==> connecto_flutter-0.0.5.tar.gz: lib/IdentifyEventModel.dart <==
import 'TrackEventModel.dart';

class IdentifyEventModel {
  IdentifyEventModel({
    this.batch,
  });

  List<IdentifyBatch> batch;

  factory IdentifyEventModel.fromJson(Map<String, dynamic> json) => IdentifyEventModel(
        batch: List<IdentifyBatch>.from(json["batch"].map((x) => IdentifyBatch.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "batch": List<dynamic>.from(batch.map((x) => x.toJson())),
      };
}

class IdentifyBatch {
  IdentifyBatch({
    this.messageId,
    this.type,
    this.channel,
    this.context,
    this.anonymousId,
    this.userId,
    this.writeKey,
    this.timestamp,
    this.traits,
  });

  String messageId;
  String type;
  String channel;
  IdentifyContext context;
  String anonymousId;
  String userId;
  String writeKey;
  String timestamp;
  Map<String, dynamic> traits;

  factory IdentifyBatch.fromJson(Map<String, dynamic> json) => IdentifyBatch(
        messageId: json["messageId"],
        type: json["type"],
        channel: json["channel"],
        context: IdentifyContext.fromJson(json["context"]),
        anonymousId: json["anonymousId"],
        userId: json["userId"],
        writeKey: json["writeKey"],
        timestamp: json["timestamp"],
        traits: Map.from(json["traits"]),
      );

  Map<String, dynamic> toJson() => {
        "messageId": messageId,
        "type": type,
        "channel": channel,
        "context": context.toJson(),
        "anonymousId": anonymousId,
        "userId": userId,
        "writeKey": writeKey,
        "timestamp": timestamp,
        "traits": traits,
      };
}

class IdentifyContext {
  IdentifyContext({
    this.app,
    this.writeKey,
    this.contextLibrary,
    this.traits,
    this.os,
    this.timezone,
    this.screen,
    this.userAgent,
    this.locale,
    this.device,
    this.network,
  });

  App app;
  String writeKey;
  Library contextLibrary;
  Map<String, dynamic> traits;
  Library os;
  String timezone;
  Screen screen;
  String userAgent;
  String locale;
  Device device;
  Network network;

  factory IdentifyContext.fromJson(Map<String, dynamic> json) => IdentifyContext(
        app: App.fromJson(json["app"]),
        writeKey: json["writeKey"],
        contextLibrary: Library.fromJson(json["library"]),
        traits: Map.from(json["traits"]),
        os: Library.fromJson(json["os"]),
        timezone: json["timezone"],
        screen: Screen.fromJson(json["screen"]),
        userAgent: json["userAgent"],
        locale: json["locale"],
        device: Device.fromJson(json["device"]),
        network: Network.fromJson(json["network"]),
      );

  Map<String, dynamic> toJson() => {
        "app": app.toJson(),
        "writeKey": writeKey,
        "library": contextLibrary.toJson(),
        "traits": traits,
        "os": os.toJson(),
        "timezone": timezone,
        "screen": screen.toJson(),
        "userAgent": userAgent,
        "locale": locale,
        "device": device.toJson(),
        "network": network.toJson(),
      };
}

class Network {
  Network({
    this.wifi,
    this.carrier,
    this.bluetooth,
    this.cellular,
  });

  bool wifi;
  String carrier;
  bool bluetooth;
  bool cellular;

  factory Network.fromJson(Map<String, dynamic> json) => Network(
        wifi: json["wifi"],
        carrier: json["carrier"],
        bluetooth: json["bluetooth"],
        cellular: json["cellular"],
      );

  Map<String, dynamic> toJson() => {
        "wifi": wifi,
        "carrier": carrier,
        "bluetooth": bluetooth,
        "cellular": cellular,
      };
}

==> connecto_flutter-0.0.7.tar.gz: lib/IdentifyEventModel.dart <==
import 'TrackEventModel.dart';

class IdentifyEventModel {
  IdentifyEventModel({
    this.batch,
  });

  List<IdentifyBatch> batch;

  factory IdentifyEventModel.fromJson(Map<String, dynamic> json) =>
      IdentifyEventModel(
        batch: List<IdentifyBatch>.from(
            json["batch"].map((x) => IdentifyBatch.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "batch": List<dynamic>.from(batch.map((x) => x.toJson())),
      };
}

class IdentifyBatch {
  IdentifyBatch({
    this.messageId,
    this.type,
    this.channel,
    this.context,
    this.anonymousId,
    this.userId,
    this.writeKey,
    this.timestamp,
    this.traits,
  });

  String messageId;
  String type;
  String channel;
  IdentifyContext context;
  String anonymousId;
  String userId;
  String writeKey;
  String timestamp;
  Map<String, dynamic> traits;

  factory IdentifyBatch.fromJson(Map<String, dynamic> json) => IdentifyBatch(
        messageId: json["messageId"],
        type: json["type"],
        channel: json["channel"],
        context: IdentifyContext.fromJson(json["context"]),
        anonymousId: json["anonymousId"],
        userId: json["userId"],
        writeKey: json["writeKey"],
        timestamp: json["timestamp"],
        traits: Map.from(json["traits"]),
      );

  Map<String, dynamic> toJson() => {
        "messageId": messageId,
        "type": type,
        "channel": channel,
        "context": context.toJson(),
        "anonymousId": anonymousId,
        "userId": userId,
        "writeKey": writeKey,
        "timestamp": timestamp,
        "traits": traits,
      };
}

class IdentifyContext {
  IdentifyContext({
    this.app,
    this.writeKey,
    this.contextLibrary,
    this.traits,
    this.os,
    this.timezone,
    this.screen,
    this.userAgent,
    this.locale,
    this.device,
    this.network,
  });

  App app;
  String writeKey;
  Library contextLibrary;
  Map<String, dynamic> traits;
  Library os;
  String timezone;
  Screen screen;
  String userAgent;
  String locale;
  Device device;
  Network network;

  factory IdentifyContext.fromJson(Map<String, dynamic> json) =>
      IdentifyContext(
        app: App.fromJson(json["app"]),
        writeKey: json["writeKey"],
        contextLibrary: Library.fromJson(json["library"]),
        traits: Map.from(json["traits"]),
        os: Library.fromJson(json["os"]),
        timezone: json["timezone"],
        screen: Screen.fromJson(json["screen"]),
        userAgent: json["userAgent"],
        locale: json["locale"],
        device: Device.fromJson(json["device"]),
        network: Network.fromJson(json["network"]),
      );

  Map<String, dynamic> toJson() => {
        "app": app.toJson(),
        "writeKey": writeKey,
        "library": contextLibrary.toJson(),
        "traits": traits,
        "os": os.toJson(),
        "timezone": timezone,
        "screen": screen.toJson(),
        "userAgent": userAgent,
        "locale": locale,
        "device": device.toJson(),
        "network": network.toJson(),
      };
}

class Network {
  Network({
    this.wifi,
    this.carrier,
    this.bluetooth,
    this.cellular,
  });

  bool wifi;
  String carrier;
  bool bluetooth;
  bool cellular;

  factory Network.fromJson(Map<String, dynamic> json) => Network(
        wifi: json["wifi"],
        carrier: json["carrier"],
        bluetooth: json["bluetooth"],
        cellular: json["cellular"],
      );

  Map<String, dynamic> toJson() => {
        "wifi": wifi,
        "carrier": carrier,
        "bluetooth": bluetooth,
        "cellular": cellular,
      };
}
